@@ -1,3 +1,4 @@
+# coding=utf-8
 #
 # Autocomplete feature for admin panel
 #
@@ -15,14 +16,15 @@ from django.utils.translation import ugettext as _
 from django.utils.text import get_text_list
 from django.contrib.admin import ModelAdmin
 
+from django_extensions.admin.widgets import ForeignKeySearchInput
+from django_extensions.compat import get_model_compat
+
 try:
     from functools import update_wrapper
     assert update_wrapper
 except ImportError:
     from django.utils.functional import update_wrapper
 
-from django_extensions.admin.widgets import ForeignKeySearchInput
-
 
 class ForeignKeyAutocompleteAdmin(ModelAdmin):
     """Admin class for models using the autocomplete feature.
@@ -54,7 +56,7 @@ class ForeignKeyAutocompleteAdmin(ModelAdmin):
     autocomplete_limit = getattr(settings, 'FOREIGNKEY_AUTOCOMPLETE_LIMIT', None)
 
     def get_urls(self):
-        from django.conf.urls import patterns, url
+        from django.conf.urls import url
 
         def wrap(view):
             def wrapper(*args, **kwargs):
@@ -68,7 +70,16 @@ class ForeignKeyAutocompleteAdmin(ModelAdmin):
         else:
             info = self.model._meta.app_label, self.model._meta.model_name
 
-        urlpatterns = patterns('', url(r'foreignkey_autocomplete/$', wrap(self.foreignkey_autocomplete), name='%s_%s_autocomplete' % info))
+        _url = url(r'foreignkey_autocomplete/$', wrap(self.foreignkey_autocomplete), name='%s_%s_autocomplete' % info)
+
+        # django.conf.urls.patterns is deprecated in django version 1.9 and removed in django version 1.10.
+        # It is replaced by a simple Python list
+        if django.VERSION < (1, 9):
+            from django.conf.urls import patterns
+            urlpatterns = patterns('', _url)
+        else:
+            urlpatterns = [_url]
+
         urlpatterns += super(ForeignKeyAutocompleteAdmin, self).get_urls()
         return urlpatterns
 
@@ -102,7 +113,10 @@ class ForeignKeyAutocompleteAdmin(ModelAdmin):
                     return "%s__search" % field_name[1:]
                 else:
                     return "%s__icontains" % field_name
-            model = models.get_model(app_label, model_name)
+
+            # As of Django 1.7 the 'get_model' method was moved to 'apps'
+            model = get_model_compat(app_label, model_name)
+
             queryset = model._default_manager.all()
             data = ''
             if query:
@@ -152,7 +166,7 @@ class ForeignKeyAutocompleteAdmin(ModelAdmin):
         Overrides the default widget for Foreignkey fields if they are
         specified in the related_search_fields class attribute.
         """
-        if (isinstance(db_field, models.ForeignKey) and db_field.name in self.related_search_fields):
+        if isinstance(db_field, models.ForeignKey) and db_field.name in self.related_search_fields:
             model_name = db_field.rel.to._meta.object_name
             help_text = self.get_help_text(db_field.name, model_name)
             if kwargs.get('help_text'):
