@@ -1,3 +1,4 @@
+# coding=utf-8
 """
 JSONField automatically serializes most Python terms to JSON data.
 Creates a TEXT field with a default value of "{}".  See test_json.py for
@@ -10,11 +11,11 @@ more information.
      extra = json.JSONField()
 """
 from __future__ import absolute_import
+
 import six
-from decimal import Decimal
-from django.db import models
 from django.conf import settings
 from django.core.serializers.json import DjangoJSONEncoder
+from django.db import models
 
 try:
     # Django >= 1.7
@@ -31,7 +32,6 @@ def dumps(value):
 def loads(txt):
     value = json.loads(
         txt,
-        parse_float=Decimal,
         encoding=settings.DEFAULT_CHARSET
     )
     return value
@@ -90,6 +90,10 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.TextField)):
         else:
             return value
 
+    def get_prep_value(self, value):
+        """Do not call `to_python` method."""
+        return super(models.TextField, self).get_prep_value(value)
+
     def get_db_prep_save(self, value, connection, **kwargs):
         """Convert our JSON object to a string before we save"""
         if value is None and self.null:
@@ -98,7 +102,8 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.TextField)):
         # run through `dumps`
         if not isinstance(value, six.string_types):
             value = dumps(value)
-        return super(JSONField, self).get_db_prep_save(value, connection=connection)
+
+        return value
 
     def south_field_triple(self):
         """Returns a suitable description of this field for South."""
@@ -107,7 +112,7 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.TextField)):
         field_class = "django.db.models.fields.TextField"
         args, kwargs = introspector(self)
         # That's our definition!
-        return (field_class, args, kwargs)
+        return field_class, args, kwargs
 
     def deconstruct(self):
         name, path, args, kwargs = super(JSONField, self).deconstruct()
