@@ -1,14 +1,15 @@
+# coding=utf-8
 from random import choice
-from django.core.management.base import NoArgsCommand
 
 from django_extensions.management.utils import signalcommand
+from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
 
 
-class Command(NoArgsCommand):
+class Command(BaseCommand):
     help = "Generates a new SECRET_KEY that can be used in a project settings file."
 
-    requires_model_validation = False
+    requires_system_checks = False
 
     @signalcommand
-    def handle_noargs(self, **options):
+    def handle(self, *args, **options):
         return ''.join([choice('abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)') for i in range(50)])
