@@ -1,16 +1,19 @@
-from django.core.management.base import BaseCommand, CommandError
-try:
-    from django.contrib.auth import get_user_model  # Django 1.5
-except ImportError:
-    from django_extensions.future_1_5 import get_user_model
+# coding=utf-8
 import getpass
 
+from django.core.management.base import CommandError
+
+from django_extensions.compat import get_user_model
+from django_extensions.management.utils import signalcommand
+from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
+
 
 class Command(BaseCommand):
     help = "Clone of the UNIX program ``passwd'', for django.contrib.auth."
 
-    requires_model_validation = False
+    requires_system_checks = False
 
+    @signalcommand
     def handle(self, *args, **options):
         if len(args) > 1:
             raise CommandError("need exactly one or zero arguments for username")
