@@ -1,20 +1,19 @@
-from optparse import make_option
-
-from django.core.management.base import LabelCommand
-
+# coding=utf-8
 from django_extensions.management.jobs import get_jobs, print_jobs
 from django_extensions.management.utils import signalcommand
+from django_extensions.compat import CompatibilityLabelCommand as LabelCommand
 
 
 class Command(LabelCommand):
-    option_list = LabelCommand.option_list + (
-        make_option('--list', '-l', action="store_true", dest="list_jobs",
-                    help="List all jobs with their description"),
-    )
     help = "Runs scheduled maintenance jobs."
     args = "[minutely quarter_hourly hourly daily weekly monthly yearly]"
     label = ""
 
+    def add_arguments(self, parser):
+        parser.add_argument(
+            '--list', '-l', action="store_true", dest="list_jobs",
+            help="List all jobs with their description")
+
     def usage_msg(self):
         print("Run scheduled jobs. Please specify 'minutely', 'quarter_hourly', 'hourly', 'daily', 'weekly', 'monthly' or 'yearly'")
 
