@@ -1,3 +1,4 @@
+# coding=utf-8
 """
 Sync Media to S3
 ================
@@ -57,22 +58,17 @@ TODO:
 """
 import datetime
 import email
+import gzip
 import mimetypes
-from optparse import make_option
 import os
 import time
-import gzip
-try:
-    from cStringIO import StringIO
-    assert StringIO
-except ImportError:
-    from StringIO import StringIO
-
 
 from django.conf import settings
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import CommandError
 
+from django_extensions.compat import StringIO
 from django_extensions.management.utils import signalcommand
+from django_extensions.compat import CompatibilityBaseCommand as BaseCommand
 
 # Make sure boto is available
 try:
@@ -104,53 +100,57 @@ class Command(BaseCommand):
     upload_count = 0
     skip_count = 0
 
-    option_list = BaseCommand.option_list + (
-        make_option('-p', '--prefix',
-                    dest='prefix',
-                    default=getattr(settings, 'SYNC_S3_PREFIX', ''),
-                    help="The prefix to prepend to the path on S3."),
-        make_option('-d', '--dir',
-                    dest='dir',
-                    help="Custom static root directory to use"),
-        make_option('--s3host',
-                    dest='s3host',
-                    default=getattr(settings, 'AWS_S3_HOST', ''),
-                    help="The s3 host (enables connecting to other providers/regions)"),
-        make_option('--acl',
-                    dest='acl',
-                    default=getattr(settings, 'AWS_DEFAULT_ACL', 'public-read'),
-                    help="Enables to override default acl (public-read)."),
-        make_option('--gzip',
-                    action='store_true', dest='gzip', default=False,
-                    help="Enables gzipping CSS and Javascript files."),
-        make_option('--renamegzip',
-                    action='store_true', dest='renamegzip', default=False,
-                    help="Enables renaming of gzipped assets to have '.gz' appended to the filename."),
-        make_option('--expires',
-                    action='store_true', dest='expires', default=False,
-                    help="Enables setting a far future expires header."),
-        make_option('--force',
-                    action='store_true', dest='force', default=False,
-                    help="Skip the file mtime check to force upload of all files."),
-        make_option('--filter-list', dest='filter_list',
-                    action='store', default='',
-                    help="Override default directory and file exclusion filters. (enter as comma seperated line)"),
-        make_option('--invalidate', dest='invalidate', default=False,
-                    action='store_true',
-                    help='Invalidates the associated objects in CloudFront'),
-        make_option('--media-only', dest='media_only', default='',
-                    action='store_true',
-                    help="Only MEDIA_ROOT files will be uploaded to S3"),
-        make_option('--static-only', dest='static_only', default='',
-                    action='store_true',
-                    help="Only STATIC_ROOT files will be uploaded to S3"),
-    )
-
     help = 'Syncs the complete MEDIA_ROOT structure and files to S3 into the given bucket name.'
     args = 'bucket_name'
 
     can_import_settings = True
 
+    def add_arguments(self, parser):
+        parser.add_argument('-p', '--prefix',
+                    dest='prefix',
+                    default=getattr(settings, 'SYNC_S3_PREFIX', ''),
+                    help="The prefix to prepend to the path on S3.")
+        parser.add_argument('-d', '--dir',
+                    dest='dir',
+                    help="Custom static root directory to use")
+        parser.add_argument('--s3host',
+                    dest='s3host',
+                    default=getattr(settings, 'AWS_S3_HOST', ''),
+                    help="The s3 host (enables connecting to other "
+                    "providers/regions)")
+        parser.add_argument('--acl',
+                    dest='acl',
+                    default=getattr(settings, 'AWS_DEFAULT_ACL',
+                                    'public-read'),
+                    help="Enables to override default acl (public-read).")
+        parser.add_argument('--gzip',
+                    action='store_true', dest='gzip', default=False,
+                    help="Enables gzipping CSS and Javascript files.")
+        parser.add_argument('--renamegzip',
+                    action='store_true', dest='renamegzip', default=False,
+                    help="Enables renaming of gzipped assets to have '.gz' "
+                    "appended to the filename.")
+        parser.add_argument('--expires',
+                    action='store_true', dest='expires', default=False,
+                    help="Enables setting a far future expires header.")
+        parser.add_argument('--force',
+                    action='store_true', dest='force', default=False,
+                    help="Skip the file mtime check to force upload of "
+                    "all files.")
+        parser.add_argument('--filter-list', dest='filter_list',
+                    action='store', default='',
+                    help="Override default directory and file exclusion "
+                    "filters. (enter as comma seperated line)")
+        parser.add_argument('--invalidate', dest='invalidate', default=False,
+                    action='store_true',
+                    help='Invalidates the associated objects in CloudFront')
+        parser.add_argument('--media-only', dest='media_only', default='',
+                    action='store_true',
+                    help="Only MEDIA_ROOT files will be uploaded to S3")
+        parser.add_argument('--static-only', dest='static_only', default='',
+                    action='store_true',
+                    help="Only STATIC_ROOT files will be uploaded to S3")
+
     @signalcommand
     def handle(self, *args, **options):
         if not HAS_BOTO:
@@ -263,7 +263,8 @@ class Command(BaseCommand):
         """
         bucket, key = self.open_s3()
         for directory in self.DIRECTORIES:
-            os.path.walk(directory, self.upload_s3, (bucket, key, self.AWS_BUCKET_NAME, directory))
+            for root, dirs, files in os.walk(directory):
+                self.upload_s3((bucket, key, self.AWS_BUCKET_NAME, directory), root, files)
 
     def compress_string(self, s):
         """Gzip a given string."""
