@@ -1,3 +1,4 @@
+# coding=utf-8
 """
 modelviz.py - DOT file generator for Django Models
 
@@ -9,10 +10,10 @@ Based on:
 
 import datetime
 import os
+import re
 
 import six
-from django.db import models
-from django.db.models import get_models
+import django
 from django.db.models.fields.related import (
     ForeignKey, ManyToManyField, OneToOneField, RelatedField,
 )
@@ -26,12 +27,13 @@ except ImportError:
     from django.utils.encoding import smart_str as force_bytes
 
 try:
-    from django.db.models.fields.generic import GenericRelation
-    assert GenericRelation
+    from django.contrib.contenttypes.fields import GenericRelation
 except ImportError:
     from django.contrib.contenttypes.generic import GenericRelation
 
-from django_extensions.compat import get_apps
+from django_extensions.compat import (
+    get_app, get_model_compat, get_models_for_app, list_app_labels
+)
 
 
 __version__ = "1.0"
@@ -47,7 +49,9 @@ __contributors__ = [
     "Alexander Houben <alexander@houben.ch>",
     "Joern Hees <gitdev@joernhees.de>",
     "Kevin Cherepski <cherepski@gmail.com>",
-    "Jose Tomas Tocino <theom3ga@gmail.com>"
+    "Jose Tomas Tocino <theom3ga@gmail.com>",
+    "Adam Dobrawy <naczelnik@jawnosc.tk>",
+    "Mikkel Munch Mortensen <https://www.detfalskested.dk/>",
 ]
 
 
@@ -61,7 +65,30 @@ def parse_file_or_list(arg):
     return [e.strip() for e in arg.split(',')]
 
 
-def generate_dot(app_labels, **kwargs):
+def use_model(model_name, include_models, exclude_models):
+    """
+    Decide whether to use a model, based on the model name and the lists of
+    models to exclude and include.
+    """
+    # Check against exclude list.
+    if exclude_models:
+        for model_pattern in exclude_models:
+            model_pattern = \
+                '^%s$' % model_pattern.replace('*', '.*')
+            if re.search(model_pattern, model_name):
+                return False
+    # Check against exclude list.
+    elif include_models:
+        for model_pattern in include_models:
+            model_pattern = \
+                '^%s$' % model_pattern.replace('*', '.*')
+            if re.search(model_pattern, model_name):
+                return True
+    # Return `True` if `include_models` is falsey, otherwise return `False`.
+    return not include_models
+
+
+def generate_graph_data(app_labels, **kwargs):
     cli_options = kwargs.get('cli_options', None)
     disable_fields = kwargs.get('disable_fields', False)
     include_models = parse_file_or_list(kwargs.get('include_models', ""))
@@ -86,17 +113,14 @@ def generate_dot(app_labels, **kwargs):
                 return True
         return False
 
-    apps = []
     if all_applications:
-        apps = get_apps()
-
-    for app_label in app_labels:
-        app = models.get_app(app_label)
-        if app not in apps:
-            apps.append(app)
+        app_labels = list_app_labels()
 
     graphs = []
-    for app in apps:
+    for app_label in app_labels:
+        app = get_app(app_label)
+        if not app:
+            continue
         graph = Context({
             'name': '"%s"' % app.__name__,
             'app_name': "%s" % '.'.join(app.__name__.split('.')[:-1]),
@@ -104,7 +128,7 @@ def generate_dot(app_labels, **kwargs):
             'models': []
         })
 
-        appmodels = get_models(app)
+        appmodels = list(get_models_for_app(app_label))
         abstract_models = []
         for appmodel in appmodels:
             abstract_models = abstract_models + [abstract_model for abstract_model in appmodel.__bases__ if hasattr(abstract_model, '_meta') and abstract_model._meta.abstract]
@@ -132,15 +156,11 @@ def generate_dot(app_labels, **kwargs):
                 'relations': []
             }
 
-            # consider given model name ?
-            def consider(model_name):
-                if exclude_models and model_name in exclude_models:
-                    return False
-                elif include_models and model_name not in include_models:
-                    return False
-                return not include_models or model_name in include_models
-
-            if not consider(appmodel._meta.object_name):
+            if not use_model(
+                appmodel._meta.object_name,
+                include_models,
+                exclude_models
+            ):
                 continue
 
             if verbose_names and appmodel._meta.verbose_name:
@@ -213,14 +233,19 @@ def generate_dot(app_labels, **kwargs):
                     related_query_name = field.related_query_name()
                     if verbose_names and related_query_name.islower():
                         related_query_name = related_query_name.replace('_', ' ').capitalize()
-                    label += ' (%s)' % related_query_name
+                    label = '{} ({})'.format(label, force_bytes(related_query_name))
 
                 # handle self-relationships and lazy-relationships
                 if isinstance(field.rel.to, six.string_types):
                     if field.rel.to == 'self':
                         target_model = field.model
                     else:
-                        raise Exception("Lazy relationship for model (%s) must be explicit for field (%s)" % (field.model.__name__, field.name))
+                        if '.' in field.rel.to:
+                            app_label, model_name = field.rel.to.split('.', 1)
+                        else:
+                            app_label = field.model._meta.app_label
+                            model_name = field.rel.to
+                        target_model = get_model_compat(app_label, model_name)
                 else:
                     target_model = field.rel.to
 
@@ -233,7 +258,11 @@ def generate_dot(app_labels, **kwargs):
                     'arrows': extras,
                     'needs_node': True
                 }
-                if _rel not in model['relations'] and consider(_rel['target']):
+                if _rel not in model['relations'] and use_model(
+                    _rel['target'],
+                    include_models,
+                    exclude_models
+                ):
                     model['relations'].append(_rel)
 
             for field in appmodel._meta.local_fields:
@@ -278,7 +307,11 @@ def generate_dot(app_labels, **kwargs):
                             'needs_node': True,
                         }
                         # TODO: seems as if abstract models aren't part of models.getModels, which is why they are printed by this without any attributes.
-                        if _rel not in model['relations'] and consider(_rel['target']):
+                        if _rel not in model['relations'] and use_model(
+                            _rel['target'],
+                            include_models,
+                            exclude_columns
+                        ):
                             model['relations'].append(_rel)
 
             graph['models'].append(model)
@@ -296,6 +329,17 @@ def generate_dot(app_labels, **kwargs):
                     relation['needs_node'] = False
 
     now = datetime.datetime.now()
+    graph_data = {
+        'created_at': now.strftime("%Y-%m-%d %H:%M"),
+        'cli_options': cli_options,
+        'disable_fields': disable_fields,
+        'use_subgraph': use_subgraph,
+        'graphs': graphs,
+    }
+    return graph_data
+
+
+def generate_dot(graph_data):
     t = loader.get_template('django_extensions/graph_models/digraph.dot')
 
     if not isinstance(t, Template) and not (hasattr(t, 'template') and isinstance(t.template, Template)):
@@ -303,13 +347,9 @@ def generate_dot(app_labels, **kwargs):
                         "This can lead to the incorrect template rendering. "
                         "Please, check the settings.")
 
-    c = Context({
-        'created_at': now.strftime("%Y-%m-%d %H:%M"),
-        'cli_options': cli_options,
-        'disable_fields': disable_fields,
-        'use_subgraph': use_subgraph,
-        'graphs': graphs,
-    })
+    c = Context(graph_data)
+    if django.VERSION >= (1, 8):
+        c = c.flatten()
     dot = t.render(c)
 
     return dot
